==> deepin-system-monitor_6.0.7.tar.xz: BUILD/deepin-system-monitor-plugin-popup/translations/deepin-system-monitor-plugin-popup_en.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.1">
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="130"/>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
</context>
<context>
    <name>Cpu.Widget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="180"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CpuWidget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="216"/>
        <location filename="../gui/cpu_widget.cpp" line="217"/>
        <source>Utilization</source>
        <translation>Utilization</translation>
    </message>
</context>
<context>
    <name>Disk.Widget</name>
    <message>
        <location filename="../gui/disk_widget.cpp" line="228"/>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="258"/>
        <source>Read</source>
        <translation>Read</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="259"/>
        <source>Write</source>
        <translation>Write</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="42"/>
        <source>System</source>
        <translation>System</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="48"/>
        <source>Display shortcuts</source>
        <translation>Display shortcuts</translation>
    </message>
</context>
<context>
    <name>Memory.Widget</name>
    <message>
        <location filename="../gui/memory_widget.cpp" line="152"/>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="179"/>
        <location filename="../gui/memory_widget.cpp" line="188"/>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="180"/>
        <source>Not enabled</source>
        <translation>Not enabled</translation>
    </message>
</context>
<context>
    <name>Net.Widget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="259"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="260"/>
        <source>Total received</source>
        <translation>Total received</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="262"/>
        <source>Total sent</source>
        <translation>Total sent</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="261"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
</context>
<context>
    <name>NetWidget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="232"/>
        <location filename="../gui/net_widget.cpp" line="235"/>
        <source>Network</source>
        <translation>Network</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../process/process.cpp" line="67"/>
        <source>Very high</source>
        <translation>Very high</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="68"/>
        <source>High</source>
        <translation>High</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="69"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="70"/>
        <source>Low</source>
        <translation>Low</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="71"/>
        <source>Very low</source>
        <translation>Very low</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="72"/>
        <source>Custom</source>
        <translation>Custom</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="73"/>
        <source>Invalid</source>
        <translation>Invalid</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="162"/>
        <source>Failed to end process</source>
        <translation>Failed to end process</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="165"/>
        <source>Failed to pause process</source>
        <translation>Failed to pause process</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="168"/>
        <source>Failed to resume process</source>
        <translation>Failed to resume process</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="171"/>
        <source>Failed to kill process</source>
        <translation>Failed to kill process</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="174"/>
        <source>Unknown error</source>
        <translation>Unknown error</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="224"/>
        <source>Failed in sending signal to process</source>
        <translation>Failed in sending signal to process</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="175"/>
        <source>No response</source>
        <translation>No response</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="180"/>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="96"/>
        <location filename="../process/process_name.cpp" line="103"/>
        <location filename="../process/process_name.cpp" line="106"/>
        <source>Tray</source>
        <translation>Tray</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="76"/>
        <source>End process</source>
        <translation>End process</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="82"/>
        <source>Suspend process</source>
        <translation>Suspend process</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="88"/>
        <source>Resume process</source>
        <translation>Resume process</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="93"/>
        <source>Properties</source>
        <translation>Properties</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="99"/>
        <source>Kill process</source>
        <translation>Kill process</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="31"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="33"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="35"/>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="37"/>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Shared memory</source>
        <translation>Shared memory</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="39"/>
        <source>Virtual memory</source>
        <translation>Virtual memory</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="41"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="43"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="45"/>
        <source>Disk read</source>
        <translation>Disk read</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="47"/>
        <source>Disk write</source>
        <translation>Disk write</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="49"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="51"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="53"/>
        <source>Priority</source>
        <translation>Priority</translation>
    </message>
</context>
<context>
    <name>ProcessWidget</name>
    <message>
        <location filename="../gui/process_widget.cpp" line="65"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="72"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="182"/>
        <location filename="../gui/process_widget.cpp" line="185"/>
        <source>Processes</source>
        <translation>Processes</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="267"/>
        <source>Not support</source>
        <translation>Not support</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="123"/>
        <source>Restart</source>
        <translation>Restart</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="128"/>
        <source>Refresh</source>
        <translation>Refresh</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="69"/>
        <source>Force end application</source>
        <translation>Force end application</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="54"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="63"/>
        <source>Processes</source>
        <translation>Processes</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <source>Services</source>
        <translation>Services</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_6.5.24.tar.xz: BUILD/deepin-system-monitor-plugin-popup/translations/deepin-system-monitor-plugin-popup_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="141"/>
        <source>No search results</source>
        <translation>No search results</translation>
    </message>
</context>
<context>
    <name>Cpu.Widget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="193"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>CpuWidget</name>
    <message>
        <location filename="../gui/cpu_widget.cpp" line="229"/>
        <location filename="../gui/cpu_widget.cpp" line="231"/>
        <location filename="../gui/cpu_widget.cpp" line="232"/>
        <source>Utilization</source>
        <translation>Utilization</translation>
    </message>
</context>
<context>
    <name>Disk.Widget</name>
    <message>
        <location filename="../gui/disk_widget.cpp" line="242"/>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="276"/>
        <source>Read</source>
        <translation>Read</translation>
    </message>
    <message>
        <location filename="../gui/disk_widget.cpp" line="277"/>
        <source>Write</source>
        <translation>Write</translation>
    </message>
</context>
<context>
    <name>Memory.Widget</name>
    <message>
        <location filename="../gui/memory_widget.cpp" line="178"/>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="210"/>
        <location filename="../gui/memory_widget.cpp" line="218"/>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <location filename="../gui/memory_widget.cpp" line="211"/>
        <source>Not enabled</source>
        <translation>Not enabled</translation>
    </message>
</context>
<context>
    <name>Net.Widget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="271"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="272"/>
        <source>Total received</source>
        <translation>Total received</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="274"/>
        <source>Total sent</source>
        <translation>Total sent</translation>
    </message>
    <message>
        <location filename="../gui/net_widget.cpp" line="273"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
</context>
<context>
    <name>NetWidget</name>
    <message>
        <location filename="../gui/net_widget.cpp" line="241"/>
        <location filename="../gui/net_widget.cpp" line="243"/>
        <location filename="../gui/net_widget.cpp" line="247"/>
        <source>Network</source>
        <translation>Network</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../process/process.cpp" line="54"/>
        <source>Very high</source>
        <translation>Very high</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="55"/>
        <source>High</source>
        <translation>High</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="56"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="57"/>
        <source>Low</source>
        <translation>Low</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="58"/>
        <source>Very low</source>
        <translation>Very low</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="59"/>
        <source>Custom</source>
        <translation>Custom</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="60"/>
        <source>Invalid</source>
        <translation>Invalid</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="168"/>
        <source>Failed to end process</source>
        <translation>Failed to end process</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="171"/>
        <source>Failed to pause process</source>
        <translation>Failed to pause process</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="174"/>
        <source>Failed to resume process</source>
        <translation>Failed to resume process</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="177"/>
        <source>Failed to kill process</source>
        <translation>Failed to kill process</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="180"/>
        <source>Unknown error</source>
        <translation>Unknown error</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="239"/>
        <source>Failed in sending signal to process</source>
        <translation>Failed in sending signal to process</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="174"/>
        <source>No response</source>
        <translation>No response</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="179"/>
        <source>Suspend</source>
        <translation>Suspend</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>User</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>Memory</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>Shared memory</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>Virtual memory</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>Disk read</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>Disk write</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>Priority</translation>
    </message>
</context>
<context>
    <name>ProcessWidget</name>
    <message>
        <location filename="../gui/process_widget.cpp" line="219"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="225"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../gui/process_widget.cpp" line="203"/>
        <location filename="../gui/process_widget.cpp" line="205"/>
        <location filename="../gui/process_widget.cpp" line="209"/>
        <source>Processes</source>
        <translation>Processes</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="253"/>
        <source>Not support</source>
        <translation>Not support</translation>
    </message>
</context>
</TS>
